package cn.rankin.userservice.controller;

import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.common.utils.enums.EventTypeEnum;
import cn.rankin.data.api.user.dto.DownloadInfoDTO;
import cn.rankin.data.api.user.entity.DownloadInfo;
import cn.rankin.userservice.service.DownloadInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping(value = "/download")
public class DownloadInfoController {

    @Autowired
    private DownloadInfoService downloadInfoService;

    @RequestMapping(method = RequestMethod.POST)
    public DownloadInfo add(@RequestBody DownloadInfoDTO dto) {
        dto.setEventType(EventTypeEnum.DOWNLOAD);
        dto.setStatus(BaseStatusEnum.NORMAL);
        dto.setNeedUpdate(0);

        //TODO
        //addEventLog();

        return downloadInfoService.add(dto);
    }

    @RequestMapping(value = "/list/{uid}", method = RequestMethod.GET)
    public List<DownloadInfo> findByUserId(@PathVariable("uid") String uid){
        return downloadInfoService.findByUserId(uid,EventTypeEnum.DOWNLOAD,BaseStatusEnum.NORMAL);
    }

    @RequestMapping(value = "/{uid}", method = RequestMethod.GET)
    public DownloadInfo findByLessonUserId(@PathVariable("uid") String uid, @RequestParam("lessonId") String lessonId){
        return downloadInfoService.findByLessonUserId(uid,lessonId,EventTypeEnum.DOWNLOAD,BaseStatusEnum.NORMAL);
    }

    @RequestMapping(value = "/delete/{uid}", method = RequestMethod.DELETE)
    public DownloadInfo deleteByLessonUserId(@PathVariable("uid") String uid, @RequestParam("lessonId") String lessonId){
        return downloadInfoService.deleteByLessonUserId(uid,lessonId);
    }

    @RequestMapping(value = "/update/{uid}", method = RequestMethod.PUT)
    public DownloadInfo updateByLessonUserId(@PathVariable("uid") String uid, @RequestParam("lessonId") String lessonId){
        return downloadInfoService.updateByLessonUserId(uid,lessonId);
    }

    @RequestMapping(value = "/set/update/{lessonId}", method = RequestMethod.PUT)
    public int setUpdateByLessonId(@PathVariable("lessonId") String lessonId){
        return downloadInfoService.setUpdateByLessonId(lessonId);
    }

}
